FunctionDescription class

Describes a function exported from WebAssembly.

Inheritance
Annotations

Constructors

FunctionDescription({required int tableIndex, required String name, required int argumentCount, required Function function})
const

Properties

address → int
The address of the exported thing.
finalinherited
argumentCount → int
The amount of arguments the underyling function has.
final
function → Function
The actual function.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of the exported thing.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableIndex → int
The index of this function in the WebAssembly table. This is the same as its address.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(dynamic other) → bool
The equality operator.
override