Global class

A global is a symbol exported by the WebAssembly, that is not a function.

Inheritance
Annotations

Constructors

Global({required int address, required String name})
const

Properties

address → int
The address of the exported thing.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the exported thing.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override