Memory class

Represents the native heap.

Implemented types
Available extensions
Annotations

Properties

buffer → ByteBuffer
Can be used to directly access the memory of this object.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate<T extends NativeType>(int byteCount, {int? alignment}) → Pointer<T>
Allocates byteCount bytes of memory on the native heap.
override
call<T extends NativeType>([int count = 1]) → Pointer<T>

Available on Allocator, provided by the AllocatorAlloc extension

Allocates sizeOf<T>() * count bytes of memory using Allocator.allocate.
free(Pointer<NativeType> pointer) → void
Releases memory allocated on the native heap.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

global ↔ Memory?
The default Memory object to use.
getter/setter pair

Static Methods

init([int pointerSizeBytes = 4]) → void
Must be called before working with web_ffi to initalize all type sizes.

Constants

endianess → const Endian
The endianess of data stored.