WasmSymbol class abstract

Describes something exported by the WebAssembly.

Implementers
Annotations

Constructors

WasmSymbol({required int address, required String name})
const

Properties

address → int
The address of the exported thing.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of the exported thing.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited